<?PHP

/**
 *	Berechnet von Bytes in verschiedene Einheiten
 *
 *	Systemvoraussetzung:
 *	Linux, Windows
 *	PHP 4 >= 4.0.1, PHP 5
 *
 *	Berechnet von Bytes in verschiedene Einheiten
 *	Byte, Kilobyte, Megabyte, Gigabyte etc.
 *	Byte, Kibibyte, Mebibyte, Gibibyte etc.
 *
 * 	LICENSE: GNU General Public License (GPL)
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 2,
 *	as published by the Free Software Foundation.
 *
 *	@category   Mathematische Berechnung
 *	@author     Damir Enseleit <info@selfphp.de>
 *	@copyright  2001-2006 SELFPHP
 *	@version    $Id: size_format.php,v 0.10 2006/04/19 11:23:40 des1 Exp $
 *	@link       http://www.selfphp.de
 */

/**
 * Berechnet von Bytes in verschiedene Einheiten
 *
 * @param		integer			$size			Wert in Bytes
 * @param		bool				$praefix	Umrechnung 1000 / 1024
 * @param		bool				$short		Kurzform / Langform
 *
 * @return	mixed													
 */

function binary_multiples($size, $praefix=true, $short= true)
{

	if($praefix === true)
	{
		if($short === true)
		{
			$norm = array('B', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB');
		}
		else
		{
			$norm = array('Byte', 
										'Kilobyte', 
										'Megabyte', 
										'Gigabyte', 
										'Terabyte', 
										'Petabyte', 
										'Exabyte', 
										'Zettabyte', 
										'Yottabyte'
										);
		}
		
		$factor = 1000;
	}
	else
	{
		if($short === true)
		{
			$norm = array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB', 'YiB');
		}
		else
		{
			$norm = array('Byte', 
										'Kibibyte', 
										'Mebibyte', 
										'Gibibyte', 
										'Tebibyte', 
										'Pebibyte', 
										'Exbibyte', 
										'Zebibyte', 
										'Yobibyte'
										);
		}
		
		$factor = 1024;
		
	}
	
	$count = count($norm) -1;
	
	$x = 0;
	while ($size >= $factor && $x < $count) 
	{ 
		$size /= $factor; 
		$x++;
	} 
  
  $size = sprintf("%01.2f", $size) . ' ' . $norm[$x];

	return $size; 

}

?> 

<pre>
<?php

$test = array(1024,
							1048576,
							1073741824,
							1099511627776,
							1125899906842624,
							1152921504606846976,
							1180591620717411303424,
							1208925819614629174706176
							);

echo "Kurzform\n";
echo "--------\n";							
for($x=0;$x<count($test);$x++)
{
	echo binary_multiples($test[$x]) . "\n";
}
echo "\n";

echo "Langform\n";	
echo "--------\n";	
for($x=0;$x<count($test);$x++)
{
	echo binary_multiples($test[$x],true,false) . "\n";
}
echo "\n";

echo "Kurzform\n";	
echo "--------\n";	
for($x=0;$x<count($test);$x++)
{
	echo binary_multiples($test[$x],false) . "\n";
}
echo "\n";

echo "Langform\n";
echo "--------\n";		
for($x=0;$x<count($test);$x++)
{
	echo binary_multiples($test[$x],false,false) . "\n";
}
echo "\n";

?>
</pre>
